import { relations } from 'drizzle-orm';
import * as t from 'drizzle-orm/pg-core';
import { timestamps } from '../util';
import { permissionsToRoles, usersToPermissions } from './schema';

export const permissions = t.pgTable('permission', {
	id: t.uuid('id').primaryKey().defaultRandom(),
	name: t.text('name').notNull().unique(),
	description: t.text('description').notNull(),
	is_wildcard: t.boolean('is_wildcard').notNull(),
	...timestamps
});

export const permissionsRelations = relations(permissions, ({ many }) => ({
	permissionToRoles: many(permissionsToRoles),
	userToPermissions: many(usersToPermissions)
}));

export type Permission = typeof permissions.$inferSelect;
